print.dynet_path_trajectories: Print a temporal trajectory tree

View source: R/path-trajectory.R

print.dynet_path_trajectoriesR Documentation

Print a temporal trajectory tree

Description

Print a temporal trajectory tree

Usage

## S3 method for class 'dynet_path_trajectories'
print(x, ...)

Arguments

x

A result from path_trajectories().

...

Passed to the data frame print method.

Value

x, invisibly. Called for the side effect of printing a header naming the direction, anchor, node count, depth and number of routes, followed by the tidy table.

Examples

dn <- dynet(school_contacts)
routes <- paths(dn, from = "Ana")
trajectories <- path_trajectories(routes)
print(trajectories)

Dynet documentation built on Oct. 7, 2026, 5:08 p.m.