print.dynet_pathways: Print ranked pathways

View source: R/pathways.R

print.dynet_pathwaysR Documentation

Print ranked pathways

Description

Print ranked pathways

Usage

## S3 method for class 'dynet_pathways'
print(x, n = 12L, ...)

Arguments

x

A dynet_pathways result.

n

Number of routes to show. Defaults to twelve.

...

Ignored.

Value

x, invisibly. Called for the side effect of printing a header giving the number of distinct routes and of optimal routes counted, followed by the first n rows.

Examples

dn <- dynet(school_contacts)
routes <- pathways(dn, from = "Ana")
print(routes)

Dynet documentation built on Oct. 7, 2026, 5:08 p.m.