| remove_nodes | R Documentation |
Remove nodes from a temporal network
remove_nodes(dn, nodes, cascade = FALSE)
dn |
A temporal network from |
nodes |
Character node names. |
cascade |
Whether to remove every incident temporal tie and vertex
activity spell. The safe default, |
A new internally consistent dynet object, of the same class and
structure as the input, without the named vertices and – under
cascade = TRUE – without their ties and vertex-activity spells. At
least one temporal tie must remain.
dn <- dynet(data.frame(from = "A", to = "B", start = 0, end = 1))
dn <- add_nodes(dn, "C")
remove_nodes(dn, "C")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.