summary.dynet_animation: Summarise an animation

View source: R/animate.R

summary.dynet_animationR Documentation

Summarise an animation

Description

Summarise an animation

Usage

## S3 method for class 'dynet_animation'
summary(object, ...)

Arguments

object

A dynet_animation from animate().

...

Ignored.

Value

A one-row plain data.frame with bins, frames, fps, seconds, tween, ease, layout, format, measure (what node size follows, NA when it is constant), first_time, last_time, min_ties, max_ties, turnover (over the bins after the first that hold a tie, the median share of a bin's ties that were not active in the bin before: near 0 the film flows, near 1 every bin is a new picture; NA with a single bin) and file.

Examples

if (requireNamespace("gifski", quietly = TRUE) &&
  requireNamespace("cograph", quietly = TRUE)) {
  dn <- dynet(school_contacts)
  frames <- animate(dn, step = 6, window = 6, tween = 2)
  summary(frames)
}

Dynet documentation built on Oct. 7, 2026, 5:08 p.m.