| dyn_centrality | R Documentation |
centrality_series() and path_centrality()dyn_centrality() was split in two. Its default scope = "snapshot" is
now centrality_series(); scope = "temporal" is path_centrality()
for closeness and betweenness and reachability() for reach. The old
name still works and returns what it always returned, with a warning of
class dynet_deprecated. It will be removed in a future release.
dyn_centrality(
dn,
measure = "degree",
scope = c("snapshot", "temporal"),
sessions = c("bounded", "collapse", "separate"),
sample = NULL,
damping = 0.85,
mode = c("all", "out", "in"),
start = NULL,
end = NULL,
step = NULL,
window = NULL,
exponent = 1,
traversal_time = 0,
prestige = "indegree",
rescale = FALSE,
lambda = 1,
plot = FALSE
)
dn, measure, sessions, sample, damping, mode, start, end, step, window, exponent, prestige, rescale, lambda, plot |
As in |
scope |
|
traversal_time |
As in |
A node-level dynet_metric, as returned by the function it
forwards to.
Warning: dynet_deprecated on every call. Errors are those of the
function it forwards to, plus dynet_bad_input for mode, step or
window with scope = "temporal" and a nonzero traversal_time with
scope = "snapshot".
dn <- dynet(school_contacts)
# Warns, then returns what centrality_series(dn) returns.
dyn_centrality(dn)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.