View source: R/path-trajectory.R
| print.dynet_path_trajectories | R Documentation |
Print a temporal trajectory tree
## S3 method for class 'dynet_path_trajectories'
print(x, ...)
x |
A result from |
... |
Passed to the data frame print method. |
x, invisibly. Called for the side effect of printing a header
naming the direction, anchor, node count, depth and number of routes,
followed by the tidy table.
dn <- dynet(school_contacts)
routes <- paths(dn, from = "Ana")
trajectories <- path_trajectories(routes)
print(trajectories)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.