| print.dynet_pathways | R Documentation |
Print ranked pathways
## S3 method for class 'dynet_pathways'
print(x, n = 12L, ...)
x |
A |
n |
Number of routes to show. Defaults to twelve. |
... |
Ignored. |
x, invisibly. Called for the side effect of printing a header
giving the number of distinct routes and of optimal routes counted,
followed by the first n rows.
dn <- dynet(school_contacts)
routes <- pathways(dn, from = "Ana")
print(routes)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.