| remove_ties | R Documentation |
Remove temporal ties
remove_ties(
dn,
ties = NULL,
from = NULL,
to = NULL,
start = NULL,
end = NULL,
session = NULL
)
dn |
A temporal network from |
ties |
Which ties to remove: a condition on the spell table,
evaluated the way |
from, to, start, end, session |
Optional selectors combined by conjunction.
|
A new internally consistent dynet object, of the same class and
structure as the input, without the matched spells. At least one temporal
tie must remain. A request that matches nothing raises a condition of
class dynet_tie_not_found.
dn <- dynet(data.frame(
from = c("A", "B"), to = c("B", "C"),
start = c(0, 1), end = c(1, 2)
))
remove_ties(dn, ties = 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.